[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Koi
A simple pytorch implementation of a meta learning algorithm from OPENAI "Reptile: A scalable meta-learning algorithm"



# Appreciation
* Lucidrains
* Agorians



# Install

# Usage


# License
MIT

